@@ -11,7 +11,7 @@ Pandoc - interface to the Pandoc document converter
 
 =cut
 
-use version 0.77; our $VERSION = version->declare('0.3.0');
+use version 0.77; our $VERSION = version->declare('0.3.1');
 
 use Carp 'croak';
 use File::Which;
@@ -34,6 +34,13 @@ sub import {
     Pandoc->export_to_level(1, 'pandoc');
 }
 
+sub VERSION {
+    shift;
+    $PANDOC //= Pandoc->new;
+    $PANDOC->require(shift) if @_;
+    $PANDOC->version;
+}
+
 sub new {
     my $pandoc = bless { }, shift;
 
@@ -52,7 +59,7 @@ sub new {
     croak "pandoc executable not found\n" unless
         $out and $out =~ /^pandoc (\d+(\.\d+)+)/;
 
-    $pandoc->{version} = version->parse($1);
+    $pandoc->{version} = version->parse("v$1");
     $pandoc->{data_dir} = $1 if $out =~ /^Default user data directory: (.+)$/m;
 
     return $pandoc;
@@ -133,11 +140,29 @@ sub convert {
     return $out;
 }
 
+sub parse {
+    my $pandoc = shift;
+    my $format = shift;
+    my $json   = "";
+
+    if ($format eq 'json') {
+        $json = shift;
+    } else {
+        $pandoc->require('1.12.1');
+        $json = $pandoc->convert( $format => 'json', @_ );
+    }
+    
+    require Pandoc::Elements;
+    Pandoc::Elements::pandoc_json($json);
+}
+
 sub require {
     my ($pandoc, $version) = @_;
     $pandoc = do { $PANDOC //= Pandoc->new } if $pandoc eq 'Pandoc'; 
-    croak "pandoc $version required, only found ".$pandoc->{version}."\n"
-        unless $pandoc->version($version);
+    unless ($pandoc->version($version)) {
+        $version = version->parse($version =~ /^v/ ? $version : "v$version");
+        croak "pandoc $version required, only found ".$pandoc->{version}."\n"
+    }
     return $pandoc;
 }
 
@@ -147,8 +172,10 @@ sub version {
 
     # compare against given version
     if (@_) {
-        my $version = eval { version->parse($_[0]) } or
-            croak "Invalid version format: $_[0]";
+        my $v = shift;
+        $v = "v$v" unless $v =~ /^v/; # force dotted decimal format
+        my $version = eval { version->parse($v) } or
+            croak "Invalid version format: $v";
         return if $version > $pandoc->{version};
     }
 
@@ -238,9 +265,6 @@ __END__
   pandoc [ -f => 'html', -t => 'markdown' ], in => \$html, out => \$md;
   pandoc [ -f => 'html', -t => 'markdown' ], { in => \$html, out => \$md };
 
-  # utility method to convert from string
-  $latex = pandoc->convert( 'markdown' => 'latex', '*hello*' );
-
   # check executable
   pandoc or die "pandoc executable not found";
 
@@ -251,37 +275,53 @@ __END__
   say pandoc->bin." ".pandoc->version;
   say "Default user data directory: ".pandoc->data_dir;
 
-  # create an instance with default arguments
+  # create a new instance with default arguments
   my $md2latex = Pandoc->new(qw(-f markdown -t latex --smart));
   $md2latex->run({ in => \$markdown, out => \$latex });
 
   # set default arguments on compile time
   use Pandoc qw(-t latex);
-  use Pandoc qw(/ur/bin/pandoc --smart);
+  use Pandoc qw(/usr/bin/pandoc --smart);
   use Pandoc qw(1.16 --smart);
 
+
+  # utility method to convert from string
+  $latex = pandoc->convert( 'markdown' => 'latex', '*hello*' );
+
+  # utility method to parse abstract syntax tree
+  $doc = pandoc->parse( markdown => '*hello* **world!**' );
+
 =head1 DESCRIPTION
 
 This module provides a Perl interface to John MacFarlane's
-L<Pandoc|http://pandoc.org> document converter. The module exports utility
-function C<pandoc> but it can also be used as class.
+L<Pandoc|http://pandoc.org> document converter. The utility function
+L<pandoc|/pandoc> is exported, unless the module is imported with an empty list
+(C<use Pandoc ();>). Another utility method converts strings between different
+markup formats supported by pandoc (C<< pandoc->convert(...) >>).
+
+Importing this module with a version number (e.g. C<use Pandoc 1.13;>) will
+check version number of pandoc executable instead of version number of this
+module (C<$Pandoc::VERSION>). Additional import arguments can be passed to set
+the executable location and default arguments of the global Pandoc instance
+used by function pandoc.
 
 =head1 FUNCTIONS
 
-=head1 pandoc
+=head2 pandoc
 
-If called without parameters, this function returns a singleton instance of
+If called without parameters, this function returns a global instance of
 class Pandoc to execute L<methods|/METHODS>, or C<undef> if no pandoc
 executable was found. 
 
-=head2 pandoc ... 
+=head2 pandoc( ... ) 
 
-If called with parameters, this functions runs the pandoc executable. Arguments
-are passed as command line arguments and options control input, output, and
-error stream as described below. Returns C<0> on success.  Otherwise returns
-the the exit code of pandoc executable or C<-1> if execution failed.  Arguments
-and options can be passed as plain array/hash or as (possibly empty) reference
-in the following ways:
+If called with parameters, this functions runs the pandoc executable configured
+at the global instance of class Pandoc (C<< pandoc->bin >>). Arguments are
+passed as command line arguments and options control input, output, and error
+stream as described below. Returns C<0> on success.  Otherwise returns the the
+exit code of pandoc executable or C<-1> if execution failed.  Arguments and
+options can be passed as plain array/hash or as (possibly empty) reference in
+the following ways:
 
   pandoc @arguments, \%options;     # ok
   pandoc \@arguments, %options;     # ok
@@ -345,6 +385,18 @@ C<pandoc --version> is called for every new instance.
 Execute the pandoc executable with default arguments and optional additional
 arguments and options. See L<<function C<pandoc>|/FUNCTIONS>> for usage.
 
+=head2 convert( $from => $to, $input [, @arguments ] )
+
+Convert a string in format C<$from> to format C<$to>. Additional pandoc options
+such as C<--smart> and C<--standalone> can be passed. The result is returned
+in same utf8 mode (C<utf8::is_unicode>) as the input.
+
+=head2 parse( $from => $input [, @arguments ] )
+
+Parse a string in format C<$from> to a L<Pandoc::Document> object. Additional 
+pandoc options such as C<--smart> and C<--normalize> can be passed. This method
+requires at least pandoc version 1.12.1 and the Perl module L<Pandoc::Elements>.
+
 =head2 require( $minimum_version )
 
 Return the Pandoc instance if its version number is at least as high as the
@@ -353,20 +405,21 @@ called as constructor: C<< Pandoc->require(...) >> is equivalent to C<<
 pandoc->require >> but throws a more meaningful error message if no pandoc
 executable was found.
 
-=head2 convert( $from => $to, $input [, @arguments ] )
-
-Convert a string in format C<$from> to format C<$to>. Additional pandoc options
-such as C<--smart> and C<--standalone> can be passed. The result is returned
-in same utf8 mode (C<utf8::is_unicode>) as the input.
-
 =head2 version( [ $minimum_version ] )
 
-Return the pandoc version as L<version> object. Returns undef if the version is
-lower than a given minimum version.
+Return the pandoc version as L<version> object. The version number is
+normalized to always start with a small letter "v", for instance "v1.16.0.2" or
+"v1.17".  If a minimum version is passed, the method returns undef if the
+pandoc version is lower. To check whether pandoc is available with a given
+minimal version use one of:
+
+  Pandoc->require( $minimum_version)                # true or die
+  pandoc and pandoc->version( $minimum_version )    # true or false
 
 =head2 bin( [ $executable ] )
 
-Return or set the pandoc executable.
+Return or set the pandoc executable. Setting an new executable also updates
+version and data_dir by calling C<pandoc --version>.
 
 =head2 arguments( [ @arguments | \@arguments )
 
